# Model

- The user can use a **pre-trained model** (such model is trained to segment epithelial cells, it **may be used right away for predictions**). Press 'Go' when ready. 
- The user can **load a tensorflow model** (typically a **.h5, .json** or **.model** file). Please drag and drop the model file onto the field or browse the hard drive to it (i.e. press 'Open' button). **NB:** If the model file is just an architecture file (.json) or if it should be used with custom weights, please drag and drop weights on the weight field at the bottom of the tab. Press 'Go' when ready.
- The user can **build a new/custom model**. Set its parameters and press 'Go' when ready.